@@ -6,14 +6,23 @@ module Doorkeeper
 
         def authenticate_resource_owner!
           super.tap do |owner|
-            next unless controller_path == Doorkeeper::Rails::Routes.mapping[:authorizations][:controllers] &&
-              action_name == 'new'
-            next unless pre_auth.scopes.include?('openid')
+            next unless oidc_authorization_request?
 
-            handle_prompt_param!(owner)
-            handle_max_age_param!(owner)
+            handle_oidc_prompt_param!(owner)
+            handle_oidc_max_age_param!(owner)
           end
         rescue Errors::OpenidConnectError => exception
+          handle_oidc_error!(exception)
+        end
+
+        def oidc_authorization_request?
+          controller_path == Doorkeeper::Rails::Routes.mapping[:authorizations][:controllers] &&
+            action_name == 'new' &&
+            pre_auth.client &&
+            pre_auth.scopes.include?('openid')
+        end
+
+        def handle_oidc_error!(exception)
           # clear the previous response body to avoid a DoubleRenderError
           self.response_body = nil
 
@@ -39,7 +48,7 @@ module Doorkeeper
           end
         end
 
-        def handle_prompt_param!(owner)
+        def handle_oidc_prompt_param!(owner)
           prompt_values ||= params[:prompt].to_s.split(/ +/).uniq
 
           prompt_values.each do |prompt|
@@ -47,9 +56,9 @@ module Doorkeeper
             when 'none' then
               raise Errors::InvalidRequest if (prompt_values - [ 'none' ]).any?
               raise Errors::LoginRequired unless owner
-              raise Errors::ConsentRequired unless matching_tokens_for_resource_owner(owner).present?
+              raise Errors::ConsentRequired if oidc_consent_required?(owner)
             when 'login' then
-              reauthenticate_resource_owner(owner) if owner
+              reauthenticate_oidc_resource_owner(owner) if owner
             when 'consent' then
               render :new
             when 'select_account' then
@@ -61,7 +70,7 @@ module Doorkeeper
           end
         end
 
-        def handle_max_age_param!(owner)
+        def handle_oidc_max_age_param!(owner)
           max_age = params[:max_age].to_i
           return unless max_age > 0 && owner
 
@@ -69,11 +78,11 @@ module Doorkeeper
             &Doorkeeper::OpenidConnect.configuration.auth_time_from_resource_owner
 
           if !auth_time || (Time.zone.now - auth_time) > max_age
-            reauthenticate_resource_owner(owner)
+            reauthenticate_oidc_resource_owner(owner)
           end
         end
 
-        def reauthenticate_resource_owner(owner)
+        def reauthenticate_oidc_resource_owner(owner)
           return_to = URI.parse(request.path)
           return_to.query = request.query_parameters.tap do |params|
             params['prompt'] = params['prompt'].to_s.sub(/\blogin\s*\b/, '').strip
@@ -86,11 +95,16 @@ module Doorkeeper
           raise Errors::LoginRequired unless performed?
         end
 
-        def matching_tokens_for_resource_owner(owner)
+        def matching_tokens_for_oidc_resource_owner(owner)
           Doorkeeper::AccessToken.authorized_tokens_for(pre_auth.client.id, owner.id).select do |token|
             Doorkeeper::AccessToken.scopes_match?(token.scopes, pre_auth.scopes, pre_auth.client.scopes)
           end
         end
+
+        def oidc_consent_required?(owner)
+          return false if skip_authorization?
+          matching_tokens_for_oidc_resource_owner(owner).blank?
+        end
       end
     end
   end
